\name{ECBC}
\title{Bias correction (through CDFt) and shuffling of time series elements through Schaake Shuffle}
\usage{
ECBC(refseries, modref, modproj, raintype=FALSE, th=0,...)
}
\alias{ECBC}
\description{ECBC starts to correct statistical biases of the "modproj" (vector) series based on the relationship between "refseries" and "modref" through the CDFt method. Then the times series (vector) obtained from the bias correction of the vector "modproj" is shuffled with the Schaake Shuffle method to reconstruct the temporal structure of the "refseries" vector.
Due to the use of the Schaake.Shuffle method, the two vectors "refseries" and "modproj" must have the same length.
}
\arguments{
  \item{refseries}{Vector containing the time series of reference (e.g., observations).}
  \item{modref}{Vector time series from a model that is used to establish the correction to apply (with CDFt).}
  \item{modproj}{Vector time series (from a model) to bias correct.}
  \item{raintype}{Boolean indicating if the series are precipitation-like data, i.e., with a threshold minimum values. Default is FALSE.}
  \item{th}{Scalar corresponding to threshold minimum values. Default is 0.}
  \item{...}{Other arguments to be passed to the CDFt function.}
}
\value{Returns a vector corresponding to the shuffled bias correction (CDFt + Schaake.Shuffle) of "modproj".
}
\details{For details on the mathematical formulation of the Schaake Shuffle, see:

Vrac, M. and Friederichs, P. (2014), Multivariate - Inter-variable, spatial and temporal - bias correction. In revision.

For details on the mathematical formulation of CDF-t, see:

Vrac, M., Drobinski, P., Merlo, A., Herrmann, M., Lavaysse, C., Li, L. and Somot S. (2012): Dynamical and statistical downscaling of the French Mediterranean climate: uncertainty assessment. Nat. Hazards Earth Syst. Sci., 12, 2769-2784, www.nat-hazards-earth-syst-sci.net/12/2769/2012/, doi:10.5194/nhess-12-2769-2012 
}
\author{M. Vrac (mathieu.vrac@lsce.ipsl.fr) and P. Friederichs (pfried@uni-bonn.de)}
\seealso{\code{\link{Schaake.Shuffle}}}
\examples{
## Example

### Generation of example data (temperature-like data)
refseries <- rnorm(100,mean=0,sd=1)
modref <- rnorm(100,mean=3,sd=0.5)
modproj <- rnorm(100,mean=3,sd=0.5)

### Call of the CDFt method
ecbc = ECBC(refseries, modref, modproj)

### Plot the results
par(mfrow=c(1,2))

YL=range(refseries, modproj, modref, ecbc)
YL[2] = YL[2]+2
plot(c(1:100), ecbc,type="l",lty=2, col=2, ylim=YL, xlab="(e.g.) time", ylab="series")
lines(c(1:100),refseries,type="l",lty=1,col=2)
lines(c(1:100),modref,type="l", lty=1, col=1)
lines(c(1:100),modproj,type="l", lty=2, col=1)

legend(x=1,y=6, "refseries", lty=1, col=2, bty="n")
legend(x=1,y=5.5, "modref", lty=1, col=, bty="n")
legend(x=45,y=6, "modproj", lty=2, col=1, bty="n")
legend(x=45,y=5.5, "ecbc", lty=2, col=2, bty="n")



### Generation of example data (precipitation-like data)
refseries <- pmax(0,refseries)
modref <- pmax(2.,modref)
modproj <- pmax(2.,modproj)

### Call of the CDFt method
ecbc = ECBC(refseries, modref, modproj, raintype=TRUE, th=0)

YL=range(refseries, modproj, modref, ecbc)
YL[2] = YL[2]+2
plot(c(1:100), ecbc,type="l",lty=2, col=2, ylim=YL, xlab="(e.g.) time", ylab="series (PR-like)")
lines(c(1:100),refseries,type="l",lty=1,col=2)
lines(c(1:100),modref,type="l", lty=1, col=1)
lines(c(1:100),modproj,type="l", lty=2, col=1)

legend(x=1,y=6, "refseries", lty=1, col=2, bty="n")
legend(x=1,y=5.5, "modref", lty=1, col=, bty="n")
legend(x=45,y=6, "modproj", lty=2, col=1, bty="n")
legend(x=45,y=5.5, "ecbc", lty=2, col=2, bty="n")





}
\keyword{math}
\keyword{ts}
\keyword{distribution}
\keyword{nonparametric}
\keyword{models}
